package com.ruoyi.system.service.impl;

import java.util.List;

import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ServiceGoodsMapper;
import com.ruoyi.system.domain.ServiceGoods;
import com.ruoyi.system.service.IServiceGoodsService;

/**
 * 服务内容Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@Service
public class ServiceGoodsServiceImpl implements IServiceGoodsService 
{
    @Autowired
    private ServiceGoodsMapper serviceGoodsMapper;

    /**
     * 查询服务内容
     * 
     * @param id 服务内容主键
     * @return 服务内容
     */
    @Override
    public ServiceGoods selectServiceGoodsById(Long id)
    {
        return serviceGoodsMapper.selectServiceGoodsById(id);
    }
    /**
     * 查询服务内容列表
     *
     * @param list 服务内容
     * @return 服务内容集合
     */
    public String selectTitlesByIds(List<String> ids){
        return serviceGoodsMapper.selectTitlesByIds(ids);
    }


    /**
     * 查询服务内容列表
     * 
     * @param serviceGoods 服务内容
     * @return 服务内容
     */
    @Override
    public List<ServiceGoods> selectServiceGoodsList(ServiceGoods serviceGoods)
    {
        return serviceGoodsMapper.selectServiceGoodsList(serviceGoods);
    }

    /**
     * 新增服务内容
     * 
     * @param serviceGoods 服务内容
     * @return 结果
     */
    @Override
    public int insertServiceGoods(ServiceGoods serviceGoods)
    {
        return serviceGoodsMapper.insertServiceGoods(serviceGoods);
    }

    /**
     * 修改服务内容
     * 
     * @param serviceGoods 服务内容
     * @return 结果
     */
    @Override
    public int updateServiceGoods(ServiceGoods serviceGoods)
    {
        return serviceGoodsMapper.updateServiceGoods(serviceGoods);
    }

    /**
     * 批量删除服务内容
     * 
     * @param ids 需要删除的服务内容主键
     * @return 结果
     */
    @Override
    public int deleteServiceGoodsByIds(Long[] ids)
    {
        return serviceGoodsMapper.deleteServiceGoodsByIds(ids);
    }

    /**
     * 删除服务内容信息
     * 
     * @param id 服务内容主键
     * @return 结果
     */
    @Override
    public int deleteServiceGoodsById(Long id)
    {
        return serviceGoodsMapper.deleteServiceGoodsById(id);
    }
}
